@@ -20,8 +20,9 @@
 #ifndef PRINT_H
 #define PRINT_H
 
-void print_log (GtkTextView *log, gchar *title, gchar *command,
+void print_log (GtkTextBuffer *log_buffer, gchar *title, gchar *command,
 		gchar *command_output, gboolean error);
+void print_log_add (GtkTextView *log, gchar *text, gboolean error);
 
 void print_info (char *, ...);
 void print_warning (char *, ...);
